# --------------------------------------------------------------------------
# Copyright 2010, C12G Labs S.L.
#
# This file is part of OpenNebula VMware Drivers.
#
# OpenNebula VMware Drivers is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or the hope That it will be useful, but (at your
# option) any later version.
#
# OpenNebula VMware Drivers is distributed in WITHOUT ANY WARRANTY;
# without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License
# along with OpenNebula VMware Drivers . If not, see
# <http://www.gnu.org/licenses/>
# --------------------------------------------------------------------------

require 'OpenNebula/Image'
require 'fileutils'

module OpenNebula
    class ImageRepositoryVMware < ImageRepository
        
        def create_vmware(image, template, vmdk_path, flat_path)
            if image.nil?
                error_msg = "Image could not be found, aborting."
                return OpenNebula::Error.new(error_msg)
            end

            # ------ Check file existence ----
            if !File.exists?(vmdk_path) 
                error_msg = "Disk image file could not be found, aborting."
                return OpenNebula::Error.new(error_msg)
            end
            
            flat_path = flat_path.split(",")
            
            flat_path.each{ |flat_file|
                if !File.exists?(flat_file) 
                    error_msg = "Flat image file could not be found, aborting."
                    return OpenNebula::Error.new(error_msg)
                end
            }

            # ------ Allocate the Image ------
            result = image.allocate(template)

            if OpenNebula.is_error?(result)
                return result
            end

            # ------ Copy the Image file ------
            image.info

            Dir.mkdir(image['SOURCE'])

            result = copy(vmdk_path, image['SOURCE']+"/disk.vmdk")
            if !OpenNebula.is_error?(result)
                flat_path.each{|flat_file|
                    result = copy(flat_file,
                                  image['SOURCE']+"/"+File.basename(flat_file))                    
                }

                if OpenNebula.is_error?(result)
                    remove(image['SOURCE']+"/disk.vmdk")
                end
            end

            # ------ Enable the Image ------
            if !OpenNebula.is_error?(result)
                image.enable
            else
                image.delete
            end

            return result
        end
    end
end